/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#include "uniqueidmanager.h"
#include "coreconstants.h"

using namespace Core;

UniqueIDManager* UniqueIDManager::m_instance = 0;

UniqueIDManager::UniqueIDManager()
{
    m_instance = this;
    m_uniqueIdentifiers.insert(Constants::C_GLOBAL, Constants::C_GLOBAL_ID);
}

UniqueIDManager::~UniqueIDManager()
{
    m_instance = 0;
}

bool UniqueIDManager::hasUniqueIdentifier(const QString &id) const
{
    return m_uniqueIdentifiers.contains(id);
}

int UniqueIDManager::uniqueIdentifier(const QString &id)
{
    if (hasUniqueIdentifier(id))
        return m_uniqueIdentifiers.value(id);

    int uid = m_uniqueIdentifiers.count() + 1;
    m_uniqueIdentifiers.insert(id, uid);
    return uid;
}

QString UniqueIDManager::stringForUniqueIdentifier(int uid)
{
    return m_uniqueIdentifiers.key(uid);
}
